@@ -24,14 +24,12 @@ from mkdocstrings_handlers.python._internal.rendering import (
     do_as_modules_section,
     do_as_type_aliases_section,
     do_backlink_tree,
-    do_crossref,
     do_filter_objects,
     do_format_attribute,
     do_format_code,
     do_format_signature,
     do_format_type_alias,
     do_get_template,
-    do_multi_crossref,
     do_order_members,
     do_split_path,
     do_stash_crossref,
@@ -59,14 +57,12 @@ __all__ = [
     "do_as_modules_section",
     "do_as_type_aliases_section",
     "do_backlink_tree",
-    "do_crossref",
     "do_filter_objects",
     "do_format_attribute",
     "do_format_code",
     "do_format_signature",
     "do_format_type_alias",
     "do_get_template",
-    "do_multi_crossref",
     "do_order_members",
     "do_split_path",
     "do_stash_crossref",
